# Generated by Django 2.2.14 on 2020-07-08 16:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0101_move_data_to_saved_for_later'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_portal_saml_configuration_screen',
            field=models.BooleanField(default=False, help_text='Specifies whether to allow access to the saml configuration screen in the admin portal'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_portal_saml_configuration_screen',
            field=models.BooleanField(default=False, help_text='Specifies whether to allow access to the saml configuration screen in the admin portal'),
        ),
    ]
