# Generated by Django 3.2.12 on 2022-04-05 20:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0011_contentmetadataitemtransmission_plugin_configuration_id'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='contentmetadataitemtransmission',
            unique_together=set(),
        ),
    ]
