# Generated by Django 4.2.10 on 2024-03-01 17:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0201_auto_20240227_2227'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisegroup',
            name='applies_to_all_contexts',
            field=models.BooleanField(default=False, help_text='When enabled, all learners connected to the org will be considered a member.', verbose_name='Set group membership to the entire org of learners.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisegroup',
            name='applies_to_all_contexts',
            field=models.BooleanField(default=False, help_text='When enabled, all learners connected to the org will be considered a member.', verbose_name='Set group membership to the entire org of learners.'),
        ),
    ]
