# Generated by Django 3.2.21 on 2023-10-02 09:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0188_alter_learnercreditenterprisecourseenrollment_enterprise_course_enrollment_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_pathways',
            field=models.BooleanField(default=True, help_text='If checked, the learners will be able to see the pathways on the learner portal dashboard.', verbose_name='Display pathways screen'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_pathways',
            field=models.BooleanField(default=True, help_text='If checked, the learners will be able to see the pathways on the learner portal dashboard.', verbose_name='Display pathways screen'),
        ),
    ]
