# Generated by Django 3.2.10 on 2022-02-01 16:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0151_add_is_active_to_invite_key'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomeruser',
            name='should_inactivate_other_customers',
            field=models.BooleanField(default=True, help_text='When enabled along with `active`, all other linked enterprise customers for this user will be marked as inactive upon save.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomeruser',
            name='should_inactivate_other_customers',
            field=models.BooleanField(default=True, help_text='When enabled along with `active`, all other linked enterprise customers for this user will be marked as inactive upon save.'),
        ),
    ]
