# Generated by Django 2.2.20 on 2021-06-08 19:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0131_auto_20210517_0924'),
    ]

    operations = [
        migrations.AddField(
            model_name='enrollmentnotificationemailtemplate',
            name='template_type',
            field=models.CharField(choices=[('SELF_ENROLL', 'Self Enrollment Template'), ('ADMIN_ENROLL', 'Admin Enrollment Template')], default='SELF_ENROLL', help_text='Use either SELF_ENROLL or ADMIN_ENROLL', max_length=255),
        ),
        migrations.AddField(
            model_name='historicalenrollmentnotificationemailtemplate',
            name='template_type',
            field=models.CharField(choices=[('SELF_ENROLL', 'Self Enrollment Template'), ('ADMIN_ENROLL', 'Admin Enrollment Template')], default='SELF_ENROLL', help_text='Use either SELF_ENROLL or ADMIN_ENROLL', max_length=255),
        ),
        migrations.AlterField(
            model_name='enrollmentnotificationemailtemplate',
            name='enterprise_customer',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enterprise_enrollment_template', to='enterprise.EnterpriseCustomer'),
        ),
    ]
